@@ -1,4 +1,4 @@
-/* $Id: cxp.h,v 1.7 2005/05/17 15:41:11 yasumichi Exp $ */
+/* $Id: cxp.h,v 1.9 2005/09/01 11:50:45 yasumichi Exp $ */
 /**
  * \if japanese
  * @file
@@ -6,7 +6,7 @@
  *
  * @author 
  * @date Fri Jan 21 2005
- * $Revision: 1.7 $
+ * $Revision: 1.9 $
  * \endif
  * \if english
  * @file
@@ -14,7 +14,7 @@
  *
  * @author Yasumichi Akahoshi
  * @date Fri Jan 21 2005
- * $Revision: 1.7 $
+ * $Revision: 1.9 $
  * \endif
  */
 
@@ -41,9 +41,9 @@
 #ifndef _CXP_H
 #define _CXP_H
 
-#include <cxp-profile.h>
 #include <cxp-handler.h>
 #include <cxp-utils.h>
+#include <cxp-mime-manager.h>
 #include <cxp-about-dialog.h>
 #include <cxp-entry-dialog.h>
 #include <cxp-gconf-pair-editor.h>
